;***NEXUS II LIBRARY OF CUSTOM CONTROLS***
;
;'Splitter control' - nxSoftware 2010.
;
;Splitter in a splitter demonstration program - demo 2.
;In this demo we show how to use a very simple NexusII callback to prevent an anchored splitter from being dragged (instead you
;have to release the anchor by clicking the gripper etc.)
;******************************************************

#INCLUDE_NEXUSII_SPLITTER = 1  ;Declare this before including the Nexus II source.

IncludePath "..\..\Source\"
  XIncludeFile "NexusII.pbi"
IncludePath ""

;///////////////////////////////////////////////////////////////////////////////////////////
Procedure.i SplitterCallback(splitter.NexusIIControl, uMsg, wParam, lParam, xParam)
  Protected result = #True
  Select uMsg
    Case #NEXUSIISPLITTER_SLIDERANCHORED
      splitter\SetAttribute(#NEXUSIISPLITTER_SLIDERTYPE, #NEXUSIISPLITTER_GRIPPERWITHNODRAG)

    Case #NEXUSIISPLITTER_ANCHORRELEASED
      splitter\SetAttribute(#NEXUSIISPLITTER_SLIDERTYPE, #NEXUSIISPLITTER_GRIPPERWITHDRAG)

    ;Uncomment the following to prevent the anchored gadget being alternated.
    ;Instead we ensure that only the first gadget is collapsed and anchored etc.
;    Case #NEXUSIISPLITTER_GRIPPERCLICKED
;      result = #NEXUSIISPLITTER_ANCHORFIRSTGADGET

  EndSelect
  ProcedureReturn result
EndProcedure
;///////////////////////////////////////////////////////////////////////////////////////////


If OpenWindow(0, 100, 100, 600, 600, "nxSoftware - Nexus II Splitter demo 1", #PB_Window_SystemMenu | #PB_Window_ScreenCentered | #PB_Window_SizeGadget | #PB_Window_MinimizeGadget | #PB_Window_MaximizeGadget | #WS_CLIPCHILDREN)
  ButtonGadget(1, 0,0,0,0, "CLICK 1")
  ButtonGadget(2, 0,0,0,0, "CLICK 2")
  EditorGadget(3,0,0,0,0)

  ;Create our splitters.
  ;Note the use of callbacks with our splitters in this demo.
    splitter1.NexusIIControl = NexusII_CreateSplitter(0, 0, 0, 0, 1, 2, 3, #NEXUSIISPLITTER_VERTICAL|#NEXUSIISPLITTER_GRIPPERWITHDRAG|#NEXUSIISPLITTER_DONOTERASECHILDRECTS, @SplitterCallback())
    If splitter1
      splitter2.NexusIIControl = NexusII_CreateSplitter(40, 40, 0, 0, 3, splitter1\GetID(), 3, #NEXUSIISPLITTER_GRIPPERWITHDRAG|#NEXUSIISPLITTER_DONOTERASECHILDRECTS, @SplitterCallback())
    EndIf

  ;Set some colors.
    If splitter1
      splitter1\SetColor(#NEXUSIISPLITTER_ANCHOREDSLIDERCOLOR, #Blue)
    EndIf
    If splitter2
      splitter2\SetColor(#NEXUSIISPLITTER_ANCHOREDSLIDERCOLOR, #Blue)
    EndIf

  Repeat
    Event = WaitWindowEvent()
    Select Event
      Case #WM_SIZE
        If splitter2
          ResizeGadget(splitter2\GetID(), #PB_Ignore, #PB_Ignore, WindowWidth(0)-80, WindowHeight(0)-80)
        EndIf
    EndSelect
  Until Event = #PB_Event_CloseWindow

  ;Tidy up.
  ;This isn't strictly needed at program's end as the objects will be cleared automatically when the parent window is destroyed.
    If splitter1
      splitter1\Destroy()
    EndIf
    If splitter2
      splitter2\Destroy()
    EndIf
EndIf
End
;///////////////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.50 (Windows - x86)
; CursorPosition = 19
; FirstLine = 9
; Folding = -
; EnableUnicode
; EnableXP
; Executable = ..\nxSplitter.exe
; CompiledLines = 1109