;/////////////////////////////////////////////////////////////////////////////////
;***NEXUS II LIBRARY OF CUSTOM CONTROLS***
;
;Public constants / structures / interfaces etc.
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTANTS (general).

;/////////////////////////////////////////////////////////////////////////////////
  ;The following constants are used to identify each type of control and are returned from the
  ;GetControlType() method of the NexusIIControl class.
    Enumeration
      #NEXUSII_SPLITTER = 1
    EndEnumeration

  ;General colors applicable to many controls. These are supplemented (where appropriate) by control specific color constants.
    Enumeration
        #NEXUSII_FRONTCOLOR = 1     ;(Tech reminder : where appropriate we use SetGadgetColor() to record this.)
        #NEXUSII_BACKCOLOR          ;(Tech reminder : where appropriate we use SetGadgetColor() to record this.)
      #NEXUSII_ENDOFCOLORCONSTANTS
    EndEnumeration
;/////////////////////////////////////////////////////////////////////////////////


;-INTERFACES.

;/////////////////////////////////////////////////////////////////////////////////
  ;The following details the main control class which is used for all NexusII controls.
  ;Calling a method on a control which does not support the given method may result in a crash (because the VTable entry will likely be zero!)
    Interface NexusIIControl
      ;General methods.
        Destroy()
        GetControlType.i()
      ;Basic control methods.
        AddColumn.i(columnIndex, text$, Width)
        AddItem.i(itemIndex, text$, imageID=0, flags=0)
        ClearAllItems()
        CloseGadgetList()
        Disable(state)
        GetAttribute.i(attribute)
        GetColor.i(colorType)
        GetData.i()
        GetHeight.i()
        GethWnd.i()
        GetID.i()                                 ;Not all NexusII controls will have a PB gadget# so take care with this method.
        GetItemAttribute.i(itemIndex, attribute, column=0)
        GetItemColor.i(itemIndex, colortype, column=0)
        GetItemData.i(itemIndex)
        GetItemState.i(itemIndex)
        GetItemText.s(itemIndex, column=0)
        GetNumberOfItems.i()
        GetState.i()
        GetText.s()
        GetWidth.i()
        GetX.i()
        GetY.i()
        Hide(state)
        OpenGadgetList(item=0)
        RemoveColumn(columnIndex)
        RemoveItem(itemIndex)
        Resize(x, y, width, height)
        SetAttribute(attribute, value)
        SetColor(colortype, color)
        SetData(Value)
        SetFont(fontID)
        SetItemAttribute(itemIndex, attribute, Value, column=0)
        SetItemColor(itemIndex, colortype, color, column=0)
        SetItemData(itemIndex, value)
        SetItemState(itemIndex, state)
        SetItemText(itemIndex, text$, column=0)
        SetState(state)
        SetText(text$)
      ;Extended control methods.
        SendMessage.i(uMsg, wParam, lParam)         ;Used to implement features not easily possible through the above list of methods.
    EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTANTS (individual controls).

;/////////////////////////////////////////////////////////////////////////////////
;-**********NexusII Splitter control
  ;Styles.
    Enumeration
      #NEXUSIISPLITTER_VERTICAL             = 1     ;Default is a horizontal splitter.    
      #NEXUSIISPLITTER_GRIPPERWITHDRAG      = 2     ;Allow a combination of gripper + drag.
      #NEXUSIISPLITTER_GRIPPERWITHNODRAG    = 4     ;Useful if only the gripper is to be utilised.
      ;Only one of the following two fields can be used.
      ;(The first takes priority).
        #NEXUSIISPLITTER_FIRSTFIXED         = 8     ;When the splitter control is resized, the first gadget will keep its size
        #NEXUSIISPLITTER_SECONDFIXED        = 16    ;When the splitter control is resized, the second gadget will keep its size
      #NEXUSIISPLITTER_DONOTERASECHILDRECTS = 32    ;Use this to reduce flicker in the case that the child gadgets will definitely
                                                    ;occupy all of their allotted space. This need not be the case (e.g. combo boxes).
                                                    ;Also useful if using custom paint instead of child gadgets.
    EndEnumeration

  ;Attributes. These can be get/set with the GetAttribute() and SetAttribute() methods.
    Enumeration
      #NEXUSIISPLITTER_FIRSTMINIMUMSIZE = 1
      #NEXUSIISPLITTER_SECONDMINIMUMSIZE
      #NEXUSIISPLITTER_FIRSTGADGET          ;When retrieving, a value of -1 means there is no gadget.
      #NEXUSIISPLITTER_SECONDGADGET         ;When retrieving, a value of -1 means there is no gadget.
      #NEXUSIISPLITTER_GRIPPERLENGTH
      #NEXUSIISPLITTER_SLIDERTYPE           ;Value = #NEXUSIISPLITTER_GRIPPERWITHDRAG or #NEXUSIISPLITTER_GRIPPERWITHDRAG
                                            ;and allows the user to switch between drag / no drag etc.
                                            ;Very useful when combined with the callback messages below.
                                            ;A value of 0 means that there is just a basic slider with no gripper.
      #NEXUSIISPLITTER_SLIDERWIDTH          ;GET only.
      #NEXUSIISPLITTER_SIZEOFSLIDERMARGIN   ;GET only.
                                            ;Number of pixels between the child gadgets and the slider. Useful if performing
                                            ;any kind of custom painting directly within the splitter.
    EndEnumeration

  ;Colors.
    Enumeration
      #NEXUSIISPLITTER_BACKCOLOR = #NEXUSII_BACKCOLOR
      #NEXUSIISPLITTER_SLIDERCOLOR
      #NEXUSIISPLITTER_ANCHOREDSLIDERCOLOR 
    EndEnumeration
    
  ;States. These can be get/set with the GetState() and SetState() methods.
  ;A positive value allows the user to set the slider position 'manually'. In such case, 'state' = GadgetWidth(gad1) + margin.
    Enumeration 
      #NEXUSIISPLITTER_ANCHORFIRSTGADGET = -2
      #NEXUSIISPLITTER_ANCHORSECONDGADGET = -3
      #NEXUSIISPLITTER_RESTORESLIDER = -4
    EndEnumeration

  ;Callback messages. Return values are ignored unless stated otherwise.
    Enumeration
      #NEXUSIISPLITTER_SLIDERANCHORED = 1 ;wParam = 1 or 2 (for the gadget just anchored), lParam = 0 etc.
      #NEXUSIISPLITTER_ANCHORRELEASED     ;wParam = 1 or 2 (for the gadget just released), lParam = 0 etc.
      #NEXUSIISPLITTER_GRIPPERCLICKED     ;wParam = 1 or 2 (to indicate which gadget would be anchored
                                          ;in the event that the operation is to proceed. 
                                          ;Return #True for the default behaviour of alternating the
                                          ;gadget to anchor.
                                          ;Alternatively return #NEXUSIISPLITTER_ANCHORFIRSTGADGET or #NEXUSIISPLITTER_ANCHORSECONDGADGET.
                                          ;Any other return will prevent any anchoring.
      #NEXUSIISPLITTER_GADGETSRESIZED     ;wParam = height (or width if using a vertical splitter) of the first gadget (or it's allotted space)
                                          ;lParam = height (or width if using a vertical splitter) of the second gadget (or it's allotted space). Return value is not used.
      #NEXUSIISPLITTER_CUSTOMPAINT        ;Advanced users only!
                                          ;Sent immediately prior to NexusII painting the slider margins and allows the developer
                                          ;to paint directly into the splitter window. Sent after the BeginPaint_() call.
                                          ;Combine with custom erasing (via subclassing) to reduce flicker etc.
                                          ;wParam = hdc, lParam = *ps.PAINTSTRUCT.
    EndEnumeration
;/////////////////////////////////////////////////////////////////////////////////


; IDE Options = PureBasic 4.50 (Windows - x86)
; CursorPosition = 1