;/////////////////////////////////////////////////////////////////////////////////
;***NEXUS II LIBRARY OF CUSTOM GADGETS***
;
;Common code file.
;/////////////////////////////////////////////////////////////////////////////////


;-INTERNAL FUNCTIONS.

;/////////////////////////////////////////////////////////////////////////////////
;The following function must be called by ALL control creation functions in order to initialise certain globals etc.
;A non-zero return indicates an 'out of memory' type error and in such cases the calling code should return with an error code of its own.
Procedure.i NexusII_Init()
  Protected *dataPointer.LONG, imageID, t1
  If gNexusII\hStateImageList = 0
    ;Create a new image list to house the state icons.
      gNexusII\hStateImageList = ImageList_Create_(16,16, #ILC_COLOR32|#ILC_MASK,0,255) ;Max 255 images.
    If gNexusII\hStateImageList
      ;Add the individual icons.
        *dataPointer = ?nexusII_Icons_Start
        While *dataPointer\l
          imageID = CatchImage(#PB_Any, *dataPointer + SizeOf(LONG))
          If imageID
            t1 = ImageList_ReplaceIcon_(gNexusII\hStateImageList,-1, ImageID(imageID))
            FreeImage(imageID)
            If t1 = -1
              Goto NexusII_Init_L1
            EndIf
          Else
NexusII_Init_L1:
            ImageList_Destroy_(gNexusII\hStateImageList)
            gNexusII\hStateImageList = 0
            Break
          EndIf
          *dataPointer + SizeOf(LONG) + *dataPointer\l
        Wend
      If gNexusII\hStateImageList
        gNexusII\cursorArrow = LoadCursor_(0, #IDC_ARROW)
        gNexusII\cursorHand = LoadCursor_(0, #IDC_HAND)
        gNexusII\cursorSizeNS = LoadCursor_(0, #IDC_SIZENS)
        gNexusII\cursorSizeWE = LoadCursor_(0, #IDC_SIZEWE)
      EndIf    
    EndIf
  EndIf
  ProcedureReturn gNexusII\hStateImageList
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-GENERIC NexusIIControl CLASS METHODS.
;These default methods (where appropriate) can be utilised by any NexusII control not requiring any custom actions.

;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_ClearAllItems(*this._NexusII_GenericTemplate)
  ClearGadgetItems(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_CloseGadgetList(*this._NexusII_GenericTemplate)
  CloseGadgetList()
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_Disable(*this._NexusII_GenericTemplate, state)
  DisableGadget(*this\ctrlID, state)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetData(*this._NexusII_GenericTemplate)
  ProcedureReturn GetGadgetData(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetHeight(*this._NexusII_GenericTemplate)
  ProcedureReturn GadgetHeight(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GethWnd(*this._NexusII_GenericTemplate)
  ProcedureReturn *this\hWnd
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetID(*this._NexusII_GenericTemplate)
  ProcedureReturn *this\ctrlID
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetItemData(*this._NexusII_GenericTemplate, itemIndex)
  ProcedureReturn GetGadgetItemData(*this\ctrlID, itemIndex)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.s NexusIIControlClass_GetItemText(*this._NexusII_GenericTemplate, itemIndex, column=0)
  ProcedureReturn GetGadgetItemText(*this\ctrlID, itemIndex, column)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetNumberOfItems(*this._NexusII_GenericTemplate)
  ProcedureReturn CountGadgetItems(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetState(*this._NexusII_GenericTemplate)
  ProcedureReturn GetGadgetState(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.s NexusIIControlClass_GetText(*this._NexusII_GenericTemplate)
  ProcedureReturn GetGadgetText(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetWidth(*this._NexusII_GenericTemplate)
  ProcedureReturn GadgetWidth(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetX(*this._NexusII_GenericTemplate)
  ProcedureReturn GadgetX(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i NexusIIControlClass_GetY(*this._NexusII_GenericTemplate)
  ProcedureReturn GadgetY(*this\ctrlID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_Hide(*this._NexusII_GenericTemplate, state)
  HideGadget(*this\ctrlID, state)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_OpenGadgetList(*this._NexusII_GenericTemplate, item=0)
  OpenGadgetList(*this\ctrlID, item)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_Resize(*this._NexusII_GenericTemplate, x, y, width, height)
  ResizeGadget(*this\ctrlID, x, y, width, height)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetData(*this._NexusII_GenericTemplate, value)
  SetGadgetData(*this\ctrlID, value)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetFont(*this._NexusII_GenericTemplate, fontID)
  SetGadgetFont(*this\ctrlID, fontID)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetItemData(*this._NexusII_GenericTemplate, itemIndex, value)
  SetGadgetItemData(*this\ctrlID, itemIndex, value)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetItemText(*this._NexusII_GenericTemplate, itemIndex, text$, column=0)
  SetGadgetItemText(*this\ctrlID, itemIndex, text$, column)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetState(*this._NexusII_GenericTemplate, state)
  SetGadgetState(*this\ctrlID, state)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure NexusIIControlClass_SetText(*this._NexusII_GenericTemplate, text$)
  SetGadgetText(*this\ctrlID, text$)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.50 (Windows - x86)
; CursorPosition = 1
; Folding = -----